%define shortname solv
%define major 0
%define libname %mklibname %shortname %major
%define libname_devel %mklibname -d %shortname


Name:   libsolv
Version:  0.6.30
%define subrel 1
Release:  %mkrel 1
License:  BSD
Url:    https://github.com/openSUSE/libsolv
Source0:   %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# Backports from upstream
# Have obsoletes account for implicit architecture coloring (mga#21827)
Patch0001:   0001-yumobs-rule-generation-also-use-implicitobsoleteuses.patch
Patch0002:   0002-Also-report-the-number-of-yumobs-rules-in-the-statis.patch
Patch0003:   0003-Fix-droporphaned-when-there-is-no-installed-repo.patch
Patch0004:   CVE-2018-20532-20534-1.patch
Patch0005:   CVE-2018-20532-20534-2.patch
Patch0006:   CVE-2018-20532-20534-3.patch
Patch0007:   CVE-2018-20532-20534-4.patch
Patch0008:   CVE-2018-20532-20534-5.patch
Patch0009:   CVE-2018-20532-20534-6.patch
Patch0010:   CVE-2018-20532-20534-7.patch

Group:    System/Libraries
Summary:  Package dependency solver
BuildRequires:  cmake 
BuildRequires:  db-devel 
BuildRequires:  libxml2-devel 
BuildRequires:  rpm-devel 
BuildRequires:  zlib-devel
BuildRequires:  bzip2-devel
BuildRequires:  swig
BuildRequires:  perl 
BuildRequires:  perl-devel 
BuildRequires:  ruby 
BuildRequires:  ruby-devel 
BuildRequires:  python3-devel
# (tv) fix build:
BuildRequires:  ruby-psych 
# For doc:
BuildRequires:  asciidoc

%description
A free package dependency solver using a satisfiability algorithm. The
library is based on two major, but independent, blocks:

- Using a dictionary approach to store and retrieve package
  and dependency information.

- Using satisfiability, a well known and researched topic, for
  resolving package dependencies.

%package -n %{libname}
Summary:  Libraries for %{name}
Group:    System/Libraries
Requires: libsolv-tools = %{version}-%{release}

%description -n %{libname}
Libraries for %{name}

%package -n %{libname_devel}
Summary:  Development files for %{name}
Group:    Development/C
Provides: %{name}-devel = %{version}-%{release}
Requires: libsolv-tools = %{version}-%{release}
Requires: %{libname} = %{version}-%{release}
Requires: cmake

%description -n %{libname_devel}
Development files for %{name}

%package doc
Summary:  Documentation for %{name}
Group:    Documentation

%description doc
Documentation for %{name}

%package tools
Summary:  A new approach to package dependency solving
Group:    System/Packaging
Requires: gzip
Requires: bzip2

%description tools
Package dependency solver tools.

%package demo
Summary:  Application demoing the libsolv library
Group:    System/Packaging
Requires: %{libname} = %{version}-%{release}
Requires: curl
Requires: gnupg2

%description demo
Applications demoing the libsolv library.

%package -n ruby-solv
Summary:  Ruby bindings for the libsolv library
Group:    Development/Ruby

%description -n ruby-solv
Ruby bindings for libsolv.

%package -n python3-solv
Summary:  Python bindings for the libsolv library
Group:    Development/Python
Obsoletes: python-solv

%description -n python3-solv
Python bindings for libsolv.

%package -n perl-solv
Summary:  Perl bindings for the libsolv library
Group:    Development/Perl

%description -n perl-solv
Perl bindings for libsolv.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DWITH_LIBXML2=1 \
       -DENABLE_PERL=1 \
       -DENABLE_PYTHON=1 \
       -DENABLE_RUBY=1 \
       -DUSE_VENDORDIRS=1 \
       -DENABLE_APPDATA=1 \
       -DENABLE_COMPS=1 -DMAGEIA=1 \
       -DENABLE_RPMDB_BYRPMHEADER=1 \
       -DENABLE_LZMA_COMPRESSION=1 \
       -DENABLE_BZIP2_COMPRESSION=1 \
       -DENABLE_SUSEREPO=1 \
       -DENABLE_HELIXREPO=1 \
       -DENABLE_DEBIAN=1 \
       -DENABLE_ARCHREPO=1 \
       -DENABLE_COMPLEX_DEPS=1 \
       -DMULTI_SEMANTICS=1

%make_build

pushd doc
cp -a ../../doc/*.txt .
cp -a ../../doc/gen gen
cp ../../doc/Makefile.gen .
make -f Makefile.gen html
popd


%install
%make_install -C build

# Fix name of repo2solv
mv %{buildroot}%{_bindir}/repo2solv.sh %{buildroot}%{_bindir}/repo2solv


%files -n %{libname}
%license LICENSE*
%doc README BUGS
%{_libdir}/libsolv.so.%{major}
%{_libdir}/libsolvext.so.%{major}

%files doc
%doc build/doc/gen/*.html

%files tools
%{_bindir}/installcheck
%{_bindir}/*solv
%exclude %{_bindir}/solv
%{_mandir}/man1/*

%files -n %{libname_devel}
%doc examples/solv
%{_libdir}/libsolv*.so
%{_includedir}/solv
%{_datadir}/cmake/Modules/FindLibSolv.cmake
%{_mandir}/man3/*
%{_libdir}/pkgconfig/libsolv*.pc

%files demo
%{_bindir}/solv

%files -n perl-solv
%doc examples/p5solv
%{perl_vendorarch}/*

%files -n ruby-solv
%doc examples/rbsolv
%{ruby_vendorarchdir}/*

%files -n python3-solv
%doc examples/pysolv
%{python3_sitearch}/*


%changelog
* Fri Apr 19 2019 mrambo3501 <mrambo3501> 0.6.30-1.1.mga6
+ Revision: 1393624
- Add debian patches for CVE-2018-2053[2-4] (mga#24563)
+ ngompa <ngompa>
- Upgrade to 0.6.30
- Backport patch from upstream to have obsoletes account for arch colors (mga#21827)
- Backport patches for adding stats to obsoletes logic and fixing droporphaned logic
- Backport fix from upstream to properly process multiple Obsoletes in a single transaction (rhbz#1470922)

* Sun Jul 02 2017 ngompa <ngompa> 0.6.28-1.mga6
+ Revision: 1108981
- Upgrade to 0.6.28

* Sun May 14 2017 ngompa <ngompa> 0.6.27-2.mga6
+ Revision: 1101053
- Backport patch to fix installed size readings (rhbz#1300801)

* Sat May 06 2017 ngompa <ngompa> 0.6.27-1.mga6
+ Revision: 1099280
- Upgrade to 0.6.27
- Switch to libxml2 for xml parsing
- Add patch to add armv5tl to armsfp arch list

* Sun Apr 02 2017 ngompa <ngompa> 0.6.26-1.mga6
+ Revision: 1095672
- Backport patches to properly replace multiarch packages (rhbz#1436110)
- Stop deleting testsolv from libsolv-tools and add libsolv-demo subpackage
- Upgrade to 0.6.26

* Fri Nov 11 2016 ngompa <ngompa> 0.6.24-1.mga6
+ Revision: 1066321
- Update to 0.6.24

* Sat Sep 03 2016 ngompa <ngompa> 0.6.23-3.mga6
+ Revision: 1049958
- Add patch to enable deep searching for packages for testcases (rhbz#1263888)
- Add patch to fix gcc6 warnings
- Add patch to guard better against corrupt RPMs

* Sat Aug 20 2016 ngompa <ngompa> 0.6.23-2.mga6
+ Revision: 1047201
- Backport patch to fix dnf --debugsolver crash (rhbz#1361831)
- Drop redundant CMake parameters

* Fri Jul 22 2016 ngompa <ngompa> 0.6.23-1.mga6
+ Revision: 1043139
- Update to 0.6.23, drop unnecessary obsoletes

* Wed Jun 15 2016 ngompa <ngompa> 0.6.22-3.mga6
+ Revision: 1021498
- More improvements to cleandeps logic

* Tue Jun 14 2016 ngompa <ngompa> 0.6.22-2.mga6
+ Revision: 1021461
- Backport patch to improve cleandeps logic (rhbz#1227066; rhbz#1284349)

* Wed Jun 08 2016 ngompa <ngompa> 0.6.22-1.mga6
+ Revision: 1020869
- Upgrade to 0.6.22

* Sun May 22 2016 ngompa <ngompa> 0.6.21-1.mga6
+ Revision: 1017443
- Update to 0.6.21, drop patches

* Fri May 13 2016 ngompa <ngompa> 0.6.20-2.mga6
+ Revision: 1014972
- Add patches for multilib and urpm-style solution ordering

* Mon Apr 11 2016 ngompa <ngompa> 0.6.20-1.mga6
+ Revision: 1000183
- Update to 0.6.20
  {U+25E6} Enable AppData and comps parsing
  {U+25E6} Enable BZip2 compression support

* Fri Mar 25 2016 tv <tv> 0.6.19-2.mga6
+ Revision: 995338
- make it mass rebuild compatible
- add doc package

* Mon Feb 15 2016 tv <tv> 0.6.19-1.mga6
+ Revision: 961399
- 0.6.19

* Sun Jan 31 2016 ngompa <ngompa> 0.6.18-1.mga6
+ Revision: 929258
- Update to 0.6.18

* Wed Dec 16 2015 ngompa <ngompa> 0.6.15-1.mga6
+ Revision: 910846
- Update to 0.6.15

* Fri Oct 09 2015 tv <tv> 0.6.14-0.20151005.1.mga6
+ Revision: 888386
- rename python-solv as python3-solv as it's really what it's
- rebuild for python 3.5
- drop patch 0 (no more needed)
- new release
- drop merged patch 1

* Fri Oct 02 2015 tv <tv> 0.6.13-0.20151002.3.mga6
+ Revision: 885739
- patch 3: enable more stuff for DNF (mga#16878)
- patch 2: auto enable RPMMD for mga (mga#16878)
- new release

* Tue Sep 29 2015 tv <tv> 0.6.13-0.20150925.3.mga6
+ Revision: 885121
- build with rich dependency support (mga#16852)

* Sat Sep 26 2015 tv <tv> 0.6.13-0.20150925.2.mga6
+ Revision: 883791
- build with -DENABLE_RPMMD=1 (mga#16821)

* Fri Sep 25 2015 tv <tv> 0.6.13-0.20150925.1.mga6
+ Revision: 883579
- new release

* Thu Sep 17 2015 tv <tv> 0.6.12-0.20150916.1.mga6
+ Revision: 880170
- new snapshot
- Mageia is now officially recognized
- patch 1: fix build

* Wed Sep 02 2015 tv <tv> 0.6.12-0.20150901.1.mga6
+ Revision: 872141
- BR python3-devel
- new release

* Sat Jun 27 2015 tv <tv> 0.6.11-1.20150622.1.mga6
+ Revision: 846065
- rebuild for soname-ifed perl

* Tue Jun 23 2015 tv <tv> 0.6.11-0.20150622.1.mga6
+ Revision: 841266
- adjust file list
- new release
- new release
- rebuild for perl-5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.6.4-1.20140925.2.mga5
+ Revision: 745445
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.6.4-1.20140925.1.mga5
+ Revision: 726895
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 tv <tv> 0.6.4-0.20140925.1.mga5
+ Revision: 724822
- even more doc

* Wed Sep 24 2014 tv <tv> 0.6.4-0.20140924.1.mga5
+ Revision: 724386
- new snapshot (doc++)

* Tue Sep 16 2014 umeabot <umeabot> 0.6.4-0.20140731.2.mga5
+ Revision: 681790
- Mageia 5 Mass Rebuild

* Sat Aug 09 2014 tv <tv> 0.6.4-0.20140731.1.mga5
+ Revision: 661268
- new release

* Sat Aug 09 2014 tv <tv> 0.6.1-0.20140418.4.mga5
+ Revision: 661262
- adjust file list
- enable support for debian & other metadata
+ pterjan <pterjan>
- Rebuild for perl 5.20
- Rebuild for new Python

* Fri Apr 18 2014 tv <tv> 0.6.1-0.20140418.1.mga5
+ Revision: 616854
- new release

* Wed Mar 26 2014 tv <tv> 0.5.1-0.20140326.1.mga5
+ Revision: 608848
- new release

* Wed Feb 26 2014 tv <tv> 0.5.0-0.20140226.1.mga5
+ Revision: 597375
- new release

* Fri Feb 14 2014 tv <tv> 0.4.4-0.20140214.1.mga5
+ Revision: 591273
- new release

* Fri Feb 07 2014 tv <tv> 0.4.0-0.20140207.1.mga5
+ Revision: 584946
- new release

* Wed Dec 18 2013 tv <tv> 0.4.0-0.20131218.1.mga4
+ Revision: 558387
- new snapshot

* Mon Oct 21 2013 umeabot <umeabot> 0.4.0-0.20130928.2.mga4
+ Revision: 538128
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 tv <tv> 0.4.0-0.20130928.1.mga4
+ Revision: 488572
- new release
- library version is now 0.4.0

* Sat Sep 21 2013 tv <tv> 0.0.0-0.20130921.1.mga4
+ Revision: 483057
- new release

* Sat Sep 21 2013 fwang <fwang> 0.0.0-0.20130611.2.mga4
+ Revision: 482941
- rebuild for ruby 2.0

* Tue Jun 11 2013 tv <tv> 0.0.0-0.20130611.1.mga4
+ Revision: 442002
- new snapshot

* Sat Jun 08 2013 tv <tv> 0.0.0-0.20130608.1.mga4
+ Revision: 440722
- new snapshot
- install new doc

* Wed May 29 2013 tv <tv> 0.0.0-0.20130523.1.mga4
+ Revision: 430007
- rebuild for new perl

* Tue Jan 22 2013 fwang <fwang> 0.0.0-0.20130114.2.mga4
+ Revision: 390773
- update rpm group

* Sat Jan 19 2013 fwang <fwang> 0.0.0-0.20130114.1.mga3
+ Revision: 389691
- more linkage fix
- link against pthread
- fix linkage
- new snapshot
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jul 31 2012 fwang <fwang> 0.0.0-0.20120701.2.mga3
+ Revision: 276444
- update file list
- specify correct libsolv switch
- obsolete old tools

* Sun Jul 01 2012 colin <colin> 0.0.0-0.20120701.1.mga3
+ Revision: 266215
- Fix more groups
- Fix groups
- Enable Helix support (needed for libzypp compilation)
- Import libsolv (based on Fedora package)


* Sun Jul 1 2012 AleÅ¡ Kozumplik <akozumpl@redhat.com> - 0.0.0-12.git1617994%%{?dist}
- Rebase to upstream 1617994.
- Support for RPM_ADD_WITH_HDRID.

* Thu Jun  7 2012 AleÅ¡ Kozumplik <akozumpl@redhat.com> - 0.0.0-11.gitd39a42b%%{?dist}
- Rebase to upstream d39a42b.
- Fix the epochs.
- Move the ruby modules into vendorarch dir, where they are expected.

* Thu May  17 2012 AleÅ¡ Kozumplik <akozumpl@redhat.com> - 0.0.0-9.git8cf7650%%{?dist}
- Rebase to upstream 8cf7650.
- ruby bindings: fix USE_VENDORDIRS for Fedora.

* Thu Apr  12 2012 AleÅ¡ Kozumplik <akozumpl@redhat.com> - 0.0.0-7.gitaf1465a2%%{?dist}
- Rebase to the upstream.
- Make repo_add_solv() work without stub repodata.

* Thu Apr  5 2012 Karel KlÃ­Ä <kklic@redhat.com> - 0.0.0-6.git80afaf7%%{?dist}
- Rebuild for the new libdb package.

* Mon Apr  2 2012 Karel KlÃ­Ä <kklic@redhat.com> - 0.0.0-5.git80afaf7%%{?dist}
- Rebuild for the new rpm package.

* Wed Mar 21 2012 AleÅ¡ KozumplÃ­k <akozumpl@redhat.com> - 0.0.0-4.git80afaf7%%{?dist}
- New upstream version, fix the .rpm release number.

* Wed Mar 21 2012 AleÅ¡ KozumplÃ­k <akozumpl@redhat.com> - 0.0.0-3.git80afaf7%%{?dist}
- New upstream version.

* Tue Feb  7 2012 Karel KlÃ­Ä <kklic@redhat.com> - 0.0.0-2.git857fe28%%{?dist}
- Adapted to Ruby 1.9.3 (workaround for broken CMake in Fedora and
  ruby template correction in bindings)

* Thu Feb  2 2012 Karel KlÃ­Ä <kklic@redhat.com> - 0.0.0-1.git857fe28
- Initial packaging
- Based on Jindra Novy's spec file
- Based on upstream spec file
